@@ -28,7 +28,7 @@ pub fn recursive_copy_dir<T: AsRef<Path>, Q: AsRef<Path>>(source: T, dest: Q) ->
             }
             // copy files
             else if file_type.is_file() {
-                fs::copy(&from, &to)?;
+                fs::copy(from, &to)?;
                 // replace CRLF with LF
                 if let Ok(data) = fs::read_to_string(from) {
                     fs::write(&to, data.replace("\r\n", "\n"))?;
