@@ -125,3 +125,14 @@ fn test_zig_gyro() {
         .unwrap()
         .contains("mkdir /gyro"));
 }
+
+#[test]
+fn test_node_turborepo_custom_app() {
+    let plan = generate_build_plan(
+        "./examples/node-turborepo",
+        vec!["NIXPACKS_TURBO_APP_NAME=docs"],
+        &GeneratePlanOptions::default(),
+    )
+    .unwrap();
+    assert!(plan.start_phase.unwrap().cmd.unwrap().contains("docs"));
+}
